Algebra
========
   
Lie Algebra Base
----------------

.. autoclass:: liesym.LieAlgebra
   :members:


A Series
---------

.. autoclass:: liesym.A
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 



B Series
---------

.. autoclass:: liesym.B
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 


C Series
---------

.. autoclass:: liesym.C
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 


D Series
---------

.. autoclass:: liesym.D
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 



E Series
---------

.. autoclass:: liesym.E
   :members:
   :undoc-members:
   :inherited-members: Basic
   :exclude-members: default_assumptions 

G2 Series
---------

.. autoclass:: liesym.G2
    :members:
    :undoc-members:
    :inherited-members: Basic
    :exclude-members: default_assumptions 

F4 Series
---------

.. autoclass:: liesym.F4
    :members:
    :undoc-members:
    :inherited-members: Basic
    :exclude-members: default_assumptions 